braindecode.datautil.create_from_mne_raw
========================================

.. currentmodule:: braindecode.datautil

.. autofunction:: create_from_mne_raw

.. include:: braindecode.datautil.create_from_mne_raw.examples

.. raw:: html

    <div style='clear:both'></div>